@@ -19,6 +19,8 @@ import urlparse
 import xml.etree.ElementTree as ET
 
 import logging
+from variety.Smart import Smart
+
 from variety import Downloader
 from variety.Util import Util
 
@@ -163,6 +165,19 @@ class MediaRssDownloader(Downloader.Downloader):
                 except:
                     pass
 
+                try:
+                    sfw = item.find("{0}sfw_info".format(VARIETY_NS))
+                    if sfw is not None:
+                        rating = int(sfw.attrib.get('rating', None))
+                        extra_metadata['sfwRating'] = rating
+
+                        if self.parent.options.safe_mode and rating < 100:
+                            logger.info(lambda: "Skipping non-safe download from VRTY MediaRss feed. "
+                                                "Is the source %s suitable for Safe mode?" % self.location)
+                            continue
+                except:
+                    pass
+
                 try:
                     extra_metadata['keywords'] = map(lambda k: k.strip(), item.find("{0}keywords".format(MEDIA_NS)).text.split(','))
                 except:
